@@ -52,8 +52,4 @@
 #' (© OpenStreetMap contributors - \url{https://www.openstreetmap.org/copyright/en}).\cr
 #' The sf dataset uses the projection WGS 84 / UTM zone 34N (EPSG:32634).\cr
 #' The csv dataset uses WGS 84 (EPSG:4326).\cr
-#'
-#'
-#'
-#' @docType package
-NULL
+"_PACKAGE"
